@@ -183,7 +183,7 @@ class FilterList(list):
         @render_to('foo.html')
         def my_entry_list(request):
             qs = Entry.objects.all()
-            filters = FilterList(qs, request, ('foo','bar'))
+            filters = FilterList(qs, request, [facet('foo'), facet('bar')])
             return dict(filters=filters)
 
     templates/foo.html:
@@ -225,8 +225,8 @@ class FilterList(list):
     views.py:
 
         FILTER_MAP = (
-            ('author_id', 'author'),    # ORM lookup, CGI param
-            ('category__slug', 'cat'),
+            facet('author_id', 'author'),    # ORM lookup, CGI param
+            facet('category__slug', 'cat'),
         )
         def my_entry_list(request):
             qs = Entry.objects.all()
@@ -244,7 +244,7 @@ class FilterList(list):
         @render_to('foo.html')
         def my_entry_list(request):
             qs = Entry.objects.filter(published=True)
-            filters = FilterList(qs, request, ('foo','bar'))
+            filters = FilterList(qs, request, [facet('foo'), facet('bar')])
             return dict(filters=filters)
 
     Post-processing:
@@ -252,7 +252,7 @@ class FilterList(list):
         @render_to('foo.html')
         def my_entry_list(request):
             qs = Entry.objects.all()
-            filters = FilterList(qs, request, ('foo','bar'))
+            filters = FilterList(qs, request, [facet('foo'), facet('bar')])
             object_list = filters.object_list
             for o in object_list:
                 o.quux = 123
@@ -269,7 +269,7 @@ class FilterList(list):
                 if isinstance(p, facet):
                     lookup, param, klass = p['lookup'], p['param'], p['kind']
                 elif isinstance(p, (tuple,list)):
-                    warnings.warn("using tuple for lookup/param coupling is"\
+                    warnings.warn("using tuple for lookup/param coupling is "\
                                   "deprecated, use filters.facet() instead.",
                                   DeprecationWarning, 2)
                     lookup, param = p
@@ -465,7 +465,6 @@ class Filter(object):
         return qs.filter(**{self.lookup: self.value})
 
 
-@Filter.register
 class RelationFilter(Filter):
     @classmethod
     def suitable_for(cls, field):
@@ -491,7 +490,17 @@ class RelationFilter(Filter):
         choices = self._annotate(choices, by=related_name)
 
         for c in choices:
-            yield FilterChoice(self, unicode(c), c.pk, c.items_count)
+            value = c.pk
+            if '__' in self.lookup:
+                try:
+                    _, attr = self.lookup.split('__')
+                except ValueError:
+                    raise ValueError('Facet lookup must contain no more than '
+                                     'two parts (got "%s")' % self.lookup)
+                else:
+                    value = getattr(c, attr)
+            yield FilterChoice(self, unicode(c), value, c.items_count)
+Filter.register(RelationFilter)
 
 
 '''
@@ -519,7 +528,6 @@ class DateDrilldownFilter(Filter):
 '''
 
 
-@Filter.register
 class BooleanFilter(Filter):
     @staticmethod
     def suitable_for(field):
@@ -539,9 +547,9 @@ class BooleanFilter(Filter):
                 v = unicode(c.get(self.lookup))
                 if v == val:
                     yield FilterChoice(self, name, val, c['items_count'])
+Filter.register(BooleanFilter)
 
 
-#@Filter.register
 class AlphabeticFilter(Filter):
     def generate_choices(self):
         choices = self.qs.values(self.lookup).distinct()
@@ -562,7 +570,6 @@ class AlphabeticFilter(Filter):
         return qs.filter(q1 | q2)
 
 
-@Filter.register
 class AllValuesFilter(Filter):
     def generate_choices(self):
         # retrieve unique values and count how many times each is used
@@ -582,6 +589,7 @@ class AllValuesFilter(Filter):
 
         for c in choices:
             yield FilterChoice(self, _title(c), _value(c), c['items_count'])
+Filter.register(AllValuesFilter)
 
 
 class FilterChoice(object):
@@ -597,7 +605,8 @@ class FilterChoice(object):
 
     @cached_property
     def urlencode(self):
-        return urlencode({self.filter.param: self.value})
+        value = self.value.encode('utf-8') if isinstance(self.value, unicode) else self.value
+        return urlencode({self.filter.param: value})
 
     @cached_property
     def active(self):
